# STRIPE-kit

[![Documentation](https://img.shields.io/badge/github-Documentation-magenta?logo=github)](https://grafczterech.github.io/STRIPE-kit)
[![PyPi](https://img.shields.io/badge/PyPI-stripe_kit-blue?logo=python)](https://pypi.org/project/stripe_kit/)

**S**treamlined **T**raining for **R**obots **I**n **P**lausible **E**nvironments

STRIPE-kit is a collection of tools and resources designed to help developers
build environments and tasks for use in Isaac Lab. The core idea is that you
use the utilities provided by STRIPE-kit to define everything you need, and
then you need not integrate anything else.

With STRIPE-kit, you can easily create and manage your Isaac Lab environments
coupled with tasks. You define the assets, terrain and STRIPE-kit will handle
the rest, alongside registering within gymnasium,

For more information, please visit the
[documentation](https://grafczterech.github.io/STRIPE-kit/index.html)
which goes into further detail regarding installation, usage and features.
